@@ -23,7 +23,7 @@ getHTML <- function(
   strings <- lapply(strings,gsub,pattern="\n",replacement="")
   strings <- lapply(strings,gsub,pattern="\r",replacement="")
   strings <- lapply(strings,gsub,pattern="\\s+",replacement=" ")
- 
+  
   return(strings)
 }
 
@@ -34,6 +34,8 @@ checkHTMLdir <- structure(function(# Extract test statistics from all HTML files
   ### String indicating the directory to be used.
   subdir = TRUE,
   ### Logical indicating whether you also want to check subfolders. Defaults to TRUE
+  extension = TRUE,
+  ### Logical indicating whether the HTML extension should be checked. Defaults to TRUE
   ...
   ### Arguments sent to  \code{\link{statcheck}}
   )
@@ -44,8 +46,10 @@ checkHTMLdir <- structure(function(# Extract test statistics from all HTML files
   ##seealso<<
   ## \code{\link{statcheck}}, \code{\link{checkPDF}}, \code{\link{checkPDFdir}}, \code{\link{checkHTML}}, \code{\link{checkdir}}
   if (missing(dir)) dir <- tk_choose.dir()
+  if (extension == TRUE) pat = ".html|.htm"
+  if (extension == FALSE) pat = ""
   
-  files <- list.files(dir,pattern=".html|.htm",full.names=TRUE,recursive=subdir)
+  files <- list.files(dir,pattern = pat, full.names = TRUE, recursive = subdir)
   
   if(length(files)==0) stop("No HTML found")
   
@@ -59,7 +63,7 @@ checkHTMLdir <- structure(function(# Extract test statistics from all HTML files
   }
   close(pb)
   names(txts) <- gsub(".html","",basename(files))
-  names(txts) <- gsub(".htm","",basename(files))
+  names(txts) <- gsub(".htm","",names(txts))
   return(statcheck(txts,...))
   ##value<<
   ## A data frame containing for each extracted statistic:
@@ -102,8 +106,11 @@ checkHTML <- structure(function(# Extract test statistics from HTML file.
   ## Note that the conversion to plain text and extraction of statistics can result in errors. Some statistical values can be missed, especially if the notation is unconvetional. It is recommended to manually check some of the results.
   ##seealso<<
   ## \code{\link{statcheck}}, \code{\link{checkPDF}}, \code{\link{checkPDFdir}}, \code{\link{checkHTMLdir}}, \code{\link{checkdir}}
+  if (missing(files)) files <- tk_choose.files()
+  
   txts <-  sapply(files,getHTML)
   names(txts) <- gsub(".html","",basename(files))
+  names(txts) <- gsub(".htm","",names(txts))
   return(statcheck(txts,...))
   ##value<<
   ## A data frame containing for each extracted statistic:
